%***************************************************************************
% Two symmetric connexions GAM and GGAM which related by
%
%       i         i       i             i
%   GGAM    := GAM    + KD   * PSI  + KD   * PSI
%        jk        jk      j      k      k      j
%
% where PSI  denotes an arbitrary covariant vector, are said to be
%          i
% projectively related. It can be shown that the curvature tensors are 
% related by
%
%     i        i        i
%   RR     := R     + KD   * ( PSI   - PSI   )
%      jkl      jkl      j        lk      kl
%                             i               i
%                         + KD   * PSI    - KD   * PSI
%                              l       jk      k      jl
%
%  where PSI   := PSI    - PSI  * PSI
%           jk       j;k      j      k
%***************************************************************************

tensor psi;
symbol gam;
index i,j,k,h,l,m,n,o,p,q;

kronecker delta kd(i,j);
riemann tensor rr(-i,-j,-k,-l),plus,minus;
christoffel symbol ggam(i,-j,-k);

rr(i,-j,-k,-l) := (rr(i,-j,-k,-l) where relation={riemann => definition});

ggam(i,-j,-k) := gam(i,-j,-k) + kd(i,-j)*psi(-k) + kd(i,-k)*psi(-j);

rr(i,-j,-k,-l) := rr(i,-j,-k,-l);

riemann tensor r(-i,-j,-k,-l),plus,minus;
christoffel symbol gam(i,-j,-k);

relation definition => riemann,
         partial => covariant;

rr(i,-j,-k,-l) := rr(i,-j,-k,-l);

relation nil; 

d(psi(-j),-k) := psi(-j,-k) + psi(-j)*psi(-k);

rr(i,-j,-k,-l);

clear rr,ggam,d(psi(-j),-k),psi;

%***************************************************************************
% A simple relation can be proved for the covariant derivative of the 
% Weyl tensor:
%    i          n - 2                         2
%   W       := ------- * ( R     - R     + ------- * ( be     - be     ) )
%     jkl;i     n - 1       jk;l    jl;k    n + 1        jl;k     jk;l
%***************************************************************************

tensor w,be;

symmetry be(-i,-j) => antisymmetric;

spacedim n;

w(i,-j,-k,-l) := r(i,-j,-k,-l) + 2*kd(i,-j)*be(-k,-l)/(n+1)
               + (kd(i,-k)*r(-j,-l) - kd(i,-l)*r(-j,-k))/(n-1)
               + 2*(kd(i,-l)*be(-j,-k)-kd(i,-k)*be(-j,-l))/(n**2-1);

d(w(i,-j,-k,-l),-i) where relation={bianchyc};

clear w,be,kd;
clear spacedim;

%***************************************************************************
%                               i
% Given any mixed tensor field H   the following combination denoted by 
%   i                            j
% HH    is a tensor field too:
%    jk
%***************************************************************************

tensor h,hh;

hh(i,-j,-k) := - (h(l,-j)*@(h(i,-k),-l) - h(l,-k)*@(h(i,-j),-l))/8
 
               + (h(i,-l)*@(h(l,-k),-j) - h(i,-l)*@(h(l,-j),-k))/8;

hh(i,-j,-k) where relation={partial=>covariant};

clear h,hh,gam;

%***************************************************************************
% A Riemannian space is recurrent if R       := k  * R      where k   is a
%                                     hijk;l     l    hijk         l
% non-zero vector. It can be shown then that
%
%   R     * k  + R     * k  + R     * k  = 0
%    hijk    l    hikl    j    hilj    k
%***************************************************************************
 
tensor k,a;
metric tensor g(i,j);

k(-l)*r(-h,-i,-j,-k) := d(r(-h,-i,-j,-k),-l);

a(-h,-i,-j,-k,-l) := r(-h,-i,-j,-k)*k(-l) + 

                     r(-h,-i,-k,-l)*k(-j) +

                     r(-h,-i,-l,-j)*k(-k);

a(-h,-i,-j,-k,-l) where relation={bianchy2=>{-h,-i,{-j,-k,-l}}};

clear k(-l)*r(-h,-i,-j,-k),k,a;

%***************************************************************************
%  The curvature tensor of a Riemannian space satisfies the identity:
%
%   R        - R        + R        - R        + R        - R        = 0
%    hijk;lm    hijk;ml    jklm;hi    jklm;ih    lmhi;jk    lmhi;kj
%***************************************************************************

tensor a;

a(-h,-i,-j,-k,-l,-m) := d(r(-h,-i,-j,-k),-l,-m) - d(r(-h,-i,-j,-k),-m,-l)

                      + d(r(-j,-k,-l,-m),-h,-i) - d(r(-j,-k,-l,-m),-i,-h)

                      + d(r(-l,-m,-h,-i),-j,-k) - d(r(-l,-m,-h,-i),-k,-j);


a(-h,-i,-j,-k,-l,-m) where relation={ordercov};

clear a;

%***************************************************************************
% Let us assume that an n-dimensional Riemannian space (n>2) has its
% curvature tensor expressible in the form
%
%   R     := g  * T   + g   * T   - g   * T   - g   * T
%    hijk     hk   ij    ij    hk    hj    ik    ik    hj
%
% It can be shown that T   is symmetric and the following relation can
%                       ij
% be proved:
%
%   2 * (n - 1)*(R     - R    ) = g   * R   - g   * R
%                 ij;k    ik;j     ij    ;k    ik    ;j
%***************************************************************************

tensor t,a;
spacedim n;

a(-h,-i,-j,-k) := - r(-h,-i,-j,-k) + g(-h,-k)*t(-i,-j) + g(-i,-j)*t(-h,-k)
                                   - g(-h,-j)*t(-i,-k) - g(-i,-k)*t(-h,-j);

relation riemann=>ricci,ricci=>invcurv;

a(j,-i,-j,-k) := a(j,-i,-j,-k);

a(j,-i,-j,i) := a(j,-i,-j,i);

relation nil;

t(h,-h) := rhs first solve(a(j,-i,-j,i),t(h,-h));

a(j,-i,-j,-k) := a(j,-i,-j,-k);

solve(a(j,-i,-j,-k),t(-i,-k));

symmetry t(-i,-j) => symmetric;

r(-i,-k) := rhs first solve(a(j,-i,-j,-k),r(-i,-k));

2*(n-1)*(d(r(-i,-j),-k)-d(r(-i,-k),-j)) - g(-i,-j)*d(r,-k) + g(-i,-k)*d(r,-j);
 
clear t,a;

%***************************************************************************
% Assuming the fisrt Bianchy identity on a Riemannian space (n>2) and
%
%    R     := K * (g   * g   - g   * g  )
%     hijk          hj    ik    hk    ij
%
% it can be proved then that K is constant.
%***************************************************************************

tensor a,k;

r(-h,-i,-j,-k) := k*(g(-h,-j)*g(-i,-k) - g(-h,-k)*g(-i,-j));

a(-h,-i,-j,-k,-l) := d(r(-h,-i,-j,-k),-l) + d(r(-h,-i,-k,-l),-j)
                   + d(r(-h,-i,-l,-j),-k);

a(h,-i,-h,i,-l);

clear a,k,r;

%***************************************************************************
% We proof that the Maxwell's equations in curved spacetime implies
% strict charge conservation,
%
%       a
%      j    = 0
%        ;a
%***************************************************************************

tensor a,f,j,k;

index a,b,c,d,e,f;

metric tensor g(-a,-b);

riemann tensor r(-a,-b,-c,-d),plus,plus;

% Vector potential A;

f(-a,-b) := d(a(-b),-a) - d(a(-a),-b); 

% Lorentz gauge condition:

d(a(-b),b) := 0;

% Maxwell's equation:

k(-b) := d(f(-a,-b),a) + 4*pi*j(-b); 

k(-b) := (k(-b) where relation={ordercov,riemann=>ricci});

k := d(k(-b),b);

k where relation={ordercov,riemann=>ricci};

end;

